==> zio-aws-emr_2.12-5.17.112.1-sources.jar: zio/aws/emr/model/ListInstanceFleetsResponse.scala <==
package zio.aws.emr.model
import zio.aws.emr.model.primitives.Marker
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListInstanceFleetsResponse(
    instanceFleets: Option[Iterable[zio.aws.emr.model.InstanceFleet]] = None,
    marker: Option[Marker] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.emr.model.ListInstanceFleetsResponse = {
    import ListInstanceFleetsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.emr.model.ListInstanceFleetsResponse
      .builder()
      .optionallyWith(
        instanceFleets.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.instanceFleets)
      .optionallyWith(
        marker.map(value => Marker.unwrap(value): java.lang.String)
      )(_.marker)
      .build()
  }
  def asReadOnly: zio.aws.emr.model.ListInstanceFleetsResponse.ReadOnly =
    zio.aws.emr.model.ListInstanceFleetsResponse.wrap(buildAwsValue())
}
object ListInstanceFleetsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.emr.model.ListInstanceFleetsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.emr.model.ListInstanceFleetsResponse =
      zio.aws.emr.model.ListInstanceFleetsResponse(
        instanceFleets.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        marker.map(value => value)
      )
    def instanceFleets: Option[List[zio.aws.emr.model.InstanceFleet.ReadOnly]]
    def marker: Option[Marker]
    def getInstanceFleets
        : ZIO[Any, AwsError, List[zio.aws.emr.model.InstanceFleet.ReadOnly]] =
      AwsError.unwrapOptionField("instanceFleets", instanceFleets)
    def getMarker: ZIO[Any, AwsError, Marker] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.emr.model.ListInstanceFleetsResponse
  ) extends zio.aws.emr.model.ListInstanceFleetsResponse.ReadOnly {
    override val instanceFleets
        : Option[List[zio.aws.emr.model.InstanceFleet.ReadOnly]] = scala
      .Option(impl.instanceFleets())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.emr.model.InstanceFleet.wrap(item)
        }.toList
      )
    override val marker: Option[Marker] = scala
      .Option(impl.marker())
      .map(value => zio.aws.emr.model.primitives.Marker(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.emr.model.ListInstanceFleetsResponse
  ): zio.aws.emr.model.ListInstanceFleetsResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-emr_2.12-6.20.42.1-sources.jar: zio/aws/emr/model/ListInstanceFleetsResponse.scala <==
package zio.aws.emr.model
import zio.aws.emr.model.primitives.Marker
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListInstanceFleetsResponse(
    instanceFleets: Optional[Iterable[zio.aws.emr.model.InstanceFleet]] =
      Optional.Absent,
    marker: Optional[Marker] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.emr.model.ListInstanceFleetsResponse = {
    import ListInstanceFleetsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.emr.model.ListInstanceFleetsResponse
      .builder()
      .optionallyWith(
        instanceFleets.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.instanceFleets)
      .optionallyWith(
        marker.map(value => Marker.unwrap(value): java.lang.String)
      )(_.marker)
      .build()
  }
  def asReadOnly: zio.aws.emr.model.ListInstanceFleetsResponse.ReadOnly =
    zio.aws.emr.model.ListInstanceFleetsResponse.wrap(buildAwsValue())
}
object ListInstanceFleetsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.emr.model.ListInstanceFleetsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.emr.model.ListInstanceFleetsResponse =
      zio.aws.emr.model.ListInstanceFleetsResponse(
        instanceFleets.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        marker.map(value => value)
      )
    def instanceFleets: Optional[List[zio.aws.emr.model.InstanceFleet.ReadOnly]]
    def marker: Optional[Marker]
    def getInstanceFleets
        : ZIO[Any, AwsError, List[zio.aws.emr.model.InstanceFleet.ReadOnly]] =
      AwsError.unwrapOptionField("instanceFleets", instanceFleets)
    def getMarker: ZIO[Any, AwsError, Marker] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.emr.model.ListInstanceFleetsResponse
  ) extends zio.aws.emr.model.ListInstanceFleetsResponse.ReadOnly {
    override val instanceFleets
        : Optional[List[zio.aws.emr.model.InstanceFleet.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.instanceFleets())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.emr.model.InstanceFleet.wrap(item)
          }.toList
        )
    override val marker: Optional[Marker] = zio.aws.core.internal
      .optionalFromNullable(impl.marker())
      .map(value => zio.aws.emr.model.primitives.Marker(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.emr.model.ListInstanceFleetsResponse
  ): zio.aws.emr.model.ListInstanceFleetsResponse.ReadOnly = new Wrapper(impl)
}
